Unknown Bird
============

by `W.S. Merwin <https://en.wikipedia.org/wiki/W._S._Merwin>`_

| Out of the dry days
| through the dusty leaves
| far across the valley
| those few notes never
| heard here before
|
| one fluted phrase
| floating over its
| wandering secret
| all at once wells up
| somewhere else
|
| and is gone before it
| goes on fallen into
| its own echo leaving
| a hollow through the air
| that is dry as before
|
| where is it from
| hardly anyone
| seems to have noticed it
| so far but who now
| would have been listening
|
| it is not native here
| that may be the one
| thing we are sure of
| it came from somewhere
| else perhaps alone
|
| so keeps on calling for
| no one who is here
| hoping to be heard
| by another of its own
| unlikely origin
|
| trying once more the same few
| notes that began the song
| of an oriole last heard
| years ago in another
| existence there
|
| it goes again tell
| no one it is here
| foreign as we are
| who are filling the days
| with a sound of our own

From The Pupil, 2002 and
`Migrations, New & Selected Poems, 2005 <https://www.coppercanyonpress.org/books/migration-new-and-selected-poems-by-w-s-merwin/>`_.
Shared as Poem of the Week on `The Merwin Conservancy <https://merwinconservancy.org/2016/01/poem-of-the-week-unknown-bird/>`_.
